@@ -4,6 +4,7 @@ import tensorflow as tf
 import buteo as beo
 
 from s2super.utils import predict, get_band_paths
+from s2super.train import wrap_metric_ignoring_conf, wrap_metric_ignoring_pred
 
 
 def conf_loss(true, pred_and_conf):
@@ -26,14 +27,23 @@ def conf_loss(true, pred_and_conf):
         tf.math.add(base, tf.math.divide(numerator, denom))
     )
 
-
 def get_s2super_model():
     super_res_dir = os.path.dirname(os.path.realpath(__file__))
-    model = tf.keras.models.load_model(os.path.join(super_res_dir, "s2super_v6"), custom_objects={ "conf_loss": conf_loss })
+    model = tf.keras.models.load_model(
+        os.path.join(super_res_dir, "s2super_v6"),
+        custom_objects={
+            "conf_loss": conf_loss,
+            "MAE": wrap_metric_ignoring_conf(tf.keras.metrics.mean_absolute_error, "MAE"),
+            "MSE": wrap_metric_ignoring_conf(tf.keras.metrics.mean_squared_error, "MSE"),
+            "MAPE": wrap_metric_ignoring_conf(tf.keras.metrics.mean_absolute_percentage_error, "MAPE"),
+            "conf_min": wrap_metric_ignoring_pred(lambda x: tf.math.reduce_min(x), "conf_min"),
+            "conf_max": wrap_metric_ignoring_pred(lambda x: tf.math.reduce_max(x), "conf_max"),
+            "conf_avg": wrap_metric_ignoring_pred(lambda x: tf.math.reduce_mean(x), "conf_avg"),
+        }
+    )
 
     return model
 
-
 def super_sample(
     data,
     fit_data=True,
